@@ -8,9 +8,6 @@ fn main() {
     let bindings = Builder::default()
         .header("src/wrapper.h")
         .layout_tests(false)
-        .default_enum_style(bindgen::EnumVariation::Rust {
-            non_exhaustive: false,
-        })
         .allowlist_recursively(false)
         .allowlist_type("libseat.*")
         .allowlist_function("libseat.*")
